/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2WHYPROCESS_H
#define SEGATEXAUDIT2WHYPROCESS_H

#include <QDialog>
#include <QTextEdit>
#include <QDir> 
#include <QVBoxLayout> 
#include <QHBoxLayout> 

class SegatexAudit2whyProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexAudit2whyProcess(QWidget *parent = 0, const char *name = 0);
public slots:
	void audit2why_base_process();
signals:
	void audit2why_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void readFromOutputFile();
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;
        QVBoxLayout *headLayout;
        QHBoxLayout *footLayout;
        QVBoxLayout *mainLayout;

};

#endif
